gcaops: Graph complex action on Poisson structures
==================================================

Description
-----------

A python package implementing the action of Kontsevich's graph complex(es)
on Poisson structures.

License
-------

MIT

Upstream Contact
----------------

- https://github.com/rburing/gcaops
- https://github.com/passagemath/passagemath-pkg-gcaops
